@@ -121,7 +121,7 @@
     </message>
     <message>
         <source>ChainTo</source>
-        <translation>ŘetězDo</translation>
+        <translation type="obsolete">ŘetězDo</translation>
     </message>
     <message>
         <source>Track</source>
@@ -129,7 +129,7 @@
     </message>
     <message>
         <source>Link</source>
-        <translation>Propojení</translation>
+        <translation type="obsolete">Propojení</translation>
     </message>
     <message>
         <source>Traffic</source>
@@ -431,6 +431,66 @@
         <source>Cut Log</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>feature</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>background</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>promo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cold</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>fade</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NoTime</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MusicLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TrafficLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Chain</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>new cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cart</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -2061,6 +2121,33 @@ Zkuste to, prosím, znovu!</translation>
         <translation type="obsolete">Unbekanntes Audioformat</translation>
     </message>
 </context>
+<context>
+    <name>RDRehash</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Internal Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDXport service returned an error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid user or password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDReport</name>
     <message>
