@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell Switcher Matrix
 //
-//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,13 +18,12 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qsqldatabase.h>
-#include <qdatetime.h>
-#include <qhostaddress.h>
-
 #ifndef RDMATRIX_H
 #define RDMATRIX_H
 
+#include <qsqldatabase.h>
+#include <qdatetime.h>
+#include <qhostaddress.h>
 
 class RDMatrix
 {
@@ -39,7 +38,7 @@ class RDMatrix
 	     BtSrc16=24,Harlond=25,Acu1p=26,LiveWireMcastGpio=27,Am16=28,
 	     LiveWireLwrpGpio=29,BtSentinel4Web=30,BtGpi16=31,ModemLines=32,
 	     SoftwareAuthority=33,Sas16000=34,RossNkScp=35,BtAdms4422=36,
-	     BtSs41Mlr=37,LastType=38};
+	     BtSs41Mlr=37,Modbus=38,KernelGpio=39,LastType=40};
   enum Endpoint {Input=0,Output=1};
   enum Mode {Stereo=0,Left=1,Right=2};
   enum VguestAttribute {VguestEngine=0,VguestDevice=1,VguestSurface=2,
