@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell User
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_user.h,v 1.21 2010/07/29 19:32:34 cvs Exp $
+//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,20 +30,21 @@
 #include <qlineedit.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
+#include <qspinbox.h>
 
 #include <rduser.h>
 
-
 class EditUser : public QDialog
 {
   Q_OBJECT
  public:
-  EditUser(const QString &user,QWidget *parent=0,const char *name=0);
+  EditUser(const QString &user,QWidget *parent=0);
   ~EditUser();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
  private slots:
+  void localAuthToggledData(bool state);
   void passwordData();
   void groupsData();
   void feedsData();
@@ -57,7 +56,13 @@ class EditUser : public QDialog
   QLineEdit *user_name_edit;
   QLineEdit *user_full_name_edit;
   QLineEdit *user_description_edit;
+  QCheckBox *user_localauth_check;
+  QLabel *user_localauth_label;
+  QLineEdit *user_pamservice_edit;
+  QLabel *user_pamservice_label;
+  QPushButton *user_password_button;
   QLineEdit *user_phone_edit;
+  QSpinBox *user_webapi_auth_spin;
   QCheckBox *user_web_box;
   QLabel *user_web_label;
   QButtonGroup *user_admin_group;
