@@ -2,9 +2,7 @@
 //
 // Edit Rivendell Service Permissions
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_user_perms.h,v 1.3 2007/02/14 21:51:02 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,16 +23,15 @@
 
 #include <qdialog.h>
 #include <qsqldatabase.h>
-#include <rlistselector.h>
+#include <rdlistselector.h>
 
 #include <rduser.h>
 
-
 class EditUserPerms : public QDialog
 {
   Q_OBJECT
  public:
-  EditUserPerms(RDUser *user,QWidget *parent=0,const char *name=0);
+  EditUserPerms(RDUser *user,QWidget *parent=0);
   ~EditUserPerms();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -44,7 +41,7 @@ class EditUserPerms : public QDialog
   void cancelData();
 
  private:
-  RListSelector *user_host_sel;
+  RDListSelector *user_host_sel;
   RDUser *user_user;
 };
 
