@@ -2,9 +2,7 @@
 //
 // Display System Information for Rivendell
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: info_dialog.h,v 1.5 2007/02/14 21:51:02 fredg Exp $
+//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -38,13 +36,11 @@
 extern const unsigned char xpm_infobanner1[];
 extern const unsigned char xpm_infobanner2[];
 
-
-
 class InfoDialog : public QDialog
 {
  Q_OBJECT
  public:
-  InfoDialog(QWidget *parent=0,const char *name=0);
+  InfoDialog(QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
