@@ -2,9 +2,7 @@
 //
 // Test a Rivendell Log Import
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: test_import.cpp,v 1.22 2010/07/29 19:32:35 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,7 +19,6 @@
 //
 
 #include <qpushbutton.h>
-#include <qlabel.h>
 #include <qpainter.h>
 #include <qmessagebox.h>
 
@@ -35,10 +32,8 @@
 #include <rdlistviewitem.h>
 #include <rdevent_line.h>
 
-
-TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,
-		       QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   QString sql;
   QDate current_date=QDate::currentDate();
@@ -50,9 +45,7 @@ TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,
   // Fix the Window Size
   //
   setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
   setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
 
   switch(test_src) {
       case RDSvc::Traffic:
@@ -75,12 +68,10 @@ TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,
   //
   // Date Selector
   //
-  test_date_edit=new QDateEdit(this,"test_date_edit");
-  test_date_edit->setGeometry(95,10,95,20);
-  QLabel *label=new QLabel(test_date_edit,tr("Test Date:"),this,"test_date_label");
-  label->setGeometry(5,10,85,20);
-  label->setFont(font);
-  label->setAlignment(AlignVCenter|AlignRight);
+  test_date_edit=new QDateEdit(this);
+  test_date_label=new QLabel(test_date_edit,tr("Test Date:"),this);
+  test_date_label->setFont(font);
+  test_date_label->setAlignment(AlignVCenter|AlignRight);
   test_date_edit->setDate(current_date);
   connect(test_date_edit,SIGNAL(valueChanged(const QDate &)),
 	  this,SLOT(dateChangedData(const QDate &)));
@@ -88,7 +79,7 @@ TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,
   //
   // Select Date Button
   //
-  QPushButton *button=new QPushButton(this,"select_date_button");
+  QPushButton *button=new QPushButton(this);
   button->setGeometry(200,5,60,30);
   button->setFont(font);
   button->setText(tr("&Select"));
@@ -97,29 +88,25 @@ TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,
   //
   // Import Button
   //
-  button=new QPushButton(this,"import_button");
-  button->setGeometry(30,45,sizeHint().width()-60,50);
-  button->setFont(font);
-  button->setText(tr("&Import"));
-  connect(button,SIGNAL(clicked()),this,SLOT(importData()));
+  test_import_button=new QPushButton(this);
+  test_import_button->setFont(font);
+  test_import_button->setText(tr("&Import"));
+  connect(test_import_button,SIGNAL(clicked()),this,SLOT(importData()));
 
   //
   // Import Filename
   //
-  test_filename_edit=new QLineEdit(this,"test_filename_edit");
+  test_filename_edit=new QLineEdit(this);
   test_filename_edit->setReadOnly(true);
-  test_filename_edit->setGeometry(10,133,sizeHint().width()-20,18);
-  label=new QLabel(test_filename_edit,tr("Using source file:"),
-		   this,"test_filename_label");
-  label->setGeometry(15,115,sizeHint().width()-30,18);
-  label->setFont(font);
+  test_filename_label=
+    new QLabel(test_filename_edit,tr("Using source file:"),this);
+  test_filename_label->setGeometry(15,115,sizeHint().width()-30,18);
+  test_filename_label->setFont(font);
 
   //
   // Events List
   //
-  test_events_list=new RDListView(this,"test_events_list");
-  test_events_list->
-    setGeometry(10,178,sizeHint().width()-20,sizeHint().height()-248);
+  test_events_list=new RDListView(this);
   test_events_list->setItemMargin(2);
   test_events_list->addColumn(tr("Start Time"));
   test_events_list->setColumnAlignment(0,AlignCenter);
@@ -136,20 +123,17 @@ TestImport::TestImport(RDSvc *svc,RDSvc::ImportSource src,
   test_events_list->addColumn(tr("Announcement Type"));
   test_events_list->setColumnAlignment(6,AlignCenter);
   test_events_list->setColumnSortType(0,RDListView::LineSort);
-  label=new QLabel(test_events_list,tr("Imported Events"),
-		   this,"test_events_label");
-  label->setGeometry(15,160,sizeHint().width()-30,18);
-  label->setFont(font);
+  test_events_label=new QLabel(test_events_list,tr("Imported Events"),this);
+  test_events_label->setGeometry(15,160,sizeHint().width()-30,18);
+  test_events_label->setFont(font);
 
   //
   //  Close Button
   //
-  button=new QPushButton(this,"close_button");
-  button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
-			     80,50);
-  button->setFont(font);
-  button->setText(tr("&Close"));
-  connect(button,SIGNAL(clicked()),this,SLOT(closeData()));
+  test_close_button=new QPushButton(this);
+  test_close_button->setFont(font);
+  test_close_button->setText(tr("&Close"));
+  connect(test_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
   dateChangedData(current_date);
 }
@@ -162,7 +146,7 @@ TestImport::~TestImport()
 
 QSize TestImport::sizeHint() const
 {
-  return QSize(270,400);
+  return QSize(700,400);
 } 
 
 
@@ -174,9 +158,9 @@ QSizePolicy TestImport::sizePolicy() const
 
 void TestImport::selectData()
 {
-  RDDateDialog *datedialog=new RDDateDialog(QDate::currentDate().year(),
-					    QDate::currentDate().year()+1,
-					    this,"timedialog");
+  RDDateDialog *datedialog=
+    new RDDateDialog(QDate::currentDate().year(),QDate::currentDate().year()+1,
+		     this);
   QDate date=test_date_edit->date();
   if(datedialog->exec(&date)<0) {
     delete datedialog;
@@ -284,7 +268,19 @@ void TestImport::paintEvent(QPaintEvent *e)
   QPainter *p=new QPainter(this);
   p->setPen(QColor(black));
   p->moveTo(10,105);
-  p->lineTo(sizeHint().width()-20,105);
+  p->lineTo(size().width()-20,105);
   p->end();
   delete p;
 }
+
+
+void TestImport::resizeEvent(QResizeEvent *e)
+{
+  test_date_edit->setGeometry(95,10,95,20);
+  test_date_label->setGeometry(5,10,85,20);
+  test_filename_edit->setGeometry(10,133,size().width()-20,18);
+  test_import_button->setGeometry(30,45,size().width()-60,50);
+  test_events_list->
+    setGeometry(10,178,size().width()-20,size().height()-248);
+  test_close_button->setGeometry(size().width()-90,size().height()-60,80,50);
+}
