@@ -351,7 +351,7 @@ un Log</translation>
     </message>
     <message>
         <source>T</source>
-        <translation>T</translation>
+        <translation type="unfinished">T</translation>
     </message>
     <message>
         <source>Pause</source>
@@ -596,6 +596,14 @@ DU LOG</translation>
         <source>Service:</source>
         <translation>Service:</translation>
     </message>
+    <message>
+        <source>Memory Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to lock all memory</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
