@@ -71,7 +71,7 @@
     </message>
     <message>
         <source>Cuts</source>
-        <translation>Audios</translation>
+        <translation type="obsolete">Audios</translation>
     </message>
     <message>
         <source>Cut Info</source>
@@ -117,7 +117,7 @@ Do you still want to proceed?</source>
     </message>
     <message>
         <source>1 Cut</source>
-        <translation>1 audio</translation>
+        <translation type="obsolete">1 audio</translation>
     </message>
     <message>
         <source>[new cart]</source>
@@ -134,7 +134,7 @@ Do you still want to proceed?</source>
     <message>
         <source>This cut is used in one or more RDCatch events!
 Do you still want to delete it?</source>
-        <translation>¡Este audio está en uso por uno o más eventos de RDCatch!
+        <translation type="obsolete">¡Este audio está en uso por uno o más eventos de RDCatch!
 ¿Desea eliminarlo de todas formas?</translation>
     </message>
     <message>
@@ -173,12 +173,65 @@ Audio</translation>
     </message>
     <message>
         <source>Unable to delete audio!</source>
-        <translation>¡No se pudo eliminar el audio!</translation>
+        <translation type="obsolete">¡No se pudo eliminar el audio!</translation>
     </message>
     <message>
         <source>No audio is present in the cut!</source>
         <translation>¡No hay audios en este cut!</translation>
     </message>
+    <message>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more cuts are used in one or more RDCatch events!
+Do you still want to delete?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete audio for cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No data copied - you must select a single cut!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must select a single cut!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ORD</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>not available</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -332,6 +385,22 @@ Lectura</translation>
         <source>Rip Track</source>
         <translation>Leyendo pista</translation>
     </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[none]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create temporary directory!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -390,7 +459,7 @@ Lectura</translation>
     <message>
         <source>Set
 &amp;Cut</source>
-        <translation>Asignar
+        <translation type="obsolete">Asignar
 &amp;Audio</translation>
     </message>
     <message>
@@ -501,16 +570,16 @@ Por favor, chequee la configuración e intente de nuevo.</translation>
     </message>
     <message>
         <source>Library Error</source>
-        <translation>Error en las bibliotecas</translation>
+        <translation type="obsolete">Error en las bibliotecas</translation>
     </message>
     <message>
         <source>Insufficient free carts available in group!</source>
-        <translation>No hay suficientes cartuchos disponibles en el grupo.</translation>
+        <translation type="obsolete">No hay suficientes cartuchos disponibles en el grupo.</translation>
     </message>
     <message>
         <source>Set All
 &amp;New Carts</source>
-        <translation>Crear como
+        <translation type="obsolete">Crear como
 &amp;cartuchos</translation>
     </message>
     <message>
@@ -544,6 +613,63 @@ Disco</translation>
         <translation>¡Lectura
 Abortada!</translation>
     </message>
+    <message>
+        <source>Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create temporary directory!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Cart
+Per Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Single
+Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set
+&amp;Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[continued]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify
+Cart Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear
+Selection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to allocate carts in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to allocate cart in group</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCart</name>
@@ -713,6 +839,54 @@ Notes</source>
         <translation>&amp;Editar
 Notas</translation>
     </message>
+    <message>
+        <source>RDLibrary - Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This cart cannot contain any additional cuts!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cond&amp;uctor:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Song &amp;ID:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Beats per Minute:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>By Specified Order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>By Weight</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Schedule Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following cut order values are assigned more than once</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Duplicate Cut Order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
@@ -814,7 +988,7 @@ Notas</translation>
     </message>
     <message>
         <source>Cart Data Dump</source>
-        <translation>Vaciado de datos de Cartuchos</translation>
+        <translation type="obsolete">Vaciado de datos de Cartuchos</translation>
     </message>
     <message>
         <source>Type:</source>
@@ -832,6 +1006,18 @@ Notas</translation>
         <source>ALL</source>
         <translation type="unfinished">TODAS</translation>
     </message>
+    <message>
+        <source>Cart Data Dump (fixed width)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart Data Dump (CSV)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Prepend Field Names</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -960,7 +1146,7 @@ Cartucho</translation>
     </message>
     <message>
         <source>PLAY ORDER</source>
-        <translation>ORDEN DE REPROD.</translation>
+        <translation type="obsolete">ORDEN DE REPROD.</translation>
     </message>
     <message>
         <source>ENFORCE LENGTH</source>
@@ -1000,11 +1186,11 @@ Cartucho</translation>
     </message>
     <message>
         <source>Sequence</source>
-        <translation>Secuencia</translation>
+        <translation type="obsolete">Secuencia</translation>
     </message>
     <message>
         <source>Random</source>
-        <translation>Aleatorio</translation>
+        <translation type="obsolete">Aleatorio</translation>
     </message>
     <message>
         <source>TFN</source>
@@ -1012,11 +1198,11 @@ Cartucho</translation>
     </message>
     <message>
         <source>RDLibrary - Host:</source>
-        <translation>RDLibrary - Servidor: </translation>
+        <translation type="obsolete">RDLibrary - Servidor: </translation>
     </message>
     <message>
         <source>, User:</source>
-        <translation>, Usuario:</translation>
+        <translation type="obsolete">, Usuario:</translation>
     </message>
     <message>
         <source>&amp;Rip
@@ -1096,6 +1282,46 @@ Do you still want to delete it?</source>
         <source> Matches</source>
         <translation> hallazgos</translation>
     </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>COMPOSER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CONDUCTOR</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PUBLISHER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow Cart Dragging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command-line option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALBUM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LABEL</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RecordCut</name>
@@ -1333,5 +1559,9 @@ Do you still want to save?</source>
         <source>AES ALARM</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
