@@ -216,6 +216,18 @@ Do you still want to delete?</source>
         <source>You must select a single cut!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>ORD</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>not available</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -446,13 +458,13 @@ Rip</source>
     <message>
         <source>Set
 &amp;Cut</source>
-        <translation>Selecionar
+        <translation type="obsolete">Selecionar
 &amp;Conteúdo</translation>
     </message>
     <message>
         <source>Set All
 &amp;New Carts</source>
-        <translation>Sel Todos
+        <translation type="obsolete">Sel Todos
 &amp;Cartões</translation>
     </message>
     <message>
@@ -515,11 +527,11 @@ Você ainda quer proceder?</translation>
     </message>
     <message>
         <source>Library Error</source>
-        <translation>Erro na Biblioteca</translation>
+        <translation type="obsolete">Erro na Biblioteca</translation>
     </message>
     <message>
         <source>Insufficient free carts available in group!</source>
-        <translation>Cartão vazios insuficientes neste grupo!</translation>
+        <translation type="obsolete">Cartão vazios insuficientes neste grupo!</translation>
     </message>
     <message>
         <source>Audio Track</source>
@@ -614,6 +626,47 @@ Disk</source>
         <source>Track</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Add Cart
+Per Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Single
+Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set
+&amp;Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[continued]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify
+Cart Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear
+Selection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to allocate carts in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to allocate cart in group</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCart</name>
@@ -811,6 +864,26 @@ limite do sistema!   Você ainda quer salvar?</translation>
         <source>Use Event Length for Now &amp;&amp; Next Updates</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>By Specified Order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>By Weight</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Schedule Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following cut order values are assigned more than once</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Duplicate Cut Order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
@@ -1479,5 +1552,9 @@ Você ainda quer salvar?</translation>
         <source>AES ALARM</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
