@@ -2,9 +2,7 @@
 //
 // Edit a Rivendell Log Marker Entry
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_marker.cpp,v 1.20 2010/07/29 19:32:37 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,8 +23,8 @@
 
 #include <edit_marker.h>
 
-EditMarker::EditMarker(RDLogLine *line,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+EditMarker::EditMarker(RDLogLine *line,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   //
   // Fix the Window Size
@@ -53,10 +51,9 @@ EditMarker::EditMarker(RDLogLine *line,QWidget *parent,const char *name)
   //
   // Time Type
   //
-  edit_timetype_box=new QCheckBox(this,"edit_timetype_box");
+  edit_timetype_box=new QCheckBox(this);
   edit_timetype_box->setGeometry(10,22,15,15);
-  edit_timetype_label=new QLabel(edit_timetype_box,tr("Start at:"),
-			   this,"edit_timetype_label");
+  edit_timetype_label=new QLabel(edit_timetype_box,tr("Start at:"),this);
   edit_timetype_label->setGeometry(30,21,85,17);
   edit_timetype_label->setFont(label_font);
   edit_timetype_label->setAlignment(AlignLeft|AlignVCenter);
@@ -64,7 +61,7 @@ EditMarker::EditMarker(RDLogLine *line,QWidget *parent,const char *name)
   //
   // Start Time
   //
-  edit_time_edit=new RDTimeEdit(this,"edit_time_edit");
+  edit_time_edit=new RDTimeEdit(this);
   edit_time_edit->setGeometry(85,19,85,20);
   edit_time_edit->setDisplay(RDTimeEdit::Hours|RDTimeEdit::Minutes|
 			     RDTimeEdit::Seconds|RDTimeEdit::Tenths);
@@ -76,8 +73,7 @@ EditMarker::EditMarker(RDLogLine *line,QWidget *parent,const char *name)
   //
   edit_grace_group
     =new QButtonGroup(1,Qt::Vertical,
-		      tr("Action If Previous Event Still Playing"),
-		      this,"edit_grace_group");
+		      tr("Action If Previous Event Still Playing"),this);
   edit_grace_group->setGeometry(175,11,435,50);
   edit_grace_group->setFont(label_font);
   edit_grace_group->setRadioButtonExclusive(true);
@@ -91,7 +87,7 @@ EditMarker::EditMarker(RDLogLine *line,QWidget *parent,const char *name)
   radio_button=new QRadioButton(tr("Wait up to"),edit_grace_group);
   edit_grace_group->insert(radio_button);
   radio_button->setFont(radio_font);
-  edit_grace_box=new QTimeEdit(this,"edit_grace_box");
+  edit_grace_box=new QTimeEdit(this);
   edit_grace_box->setGeometry(543,31,60,20);
   edit_grace_box->setDisplay(QTimeEdit::Minutes|QTimeEdit::Seconds);
   connect(edit_timetype_box,SIGNAL(toggled(bool)),
@@ -102,13 +98,12 @@ EditMarker::EditMarker(RDLogLine *line,QWidget *parent,const char *name)
   //
   // Transition Type
   //
-  edit_transtype_box=new QComboBox(this,"edit_transtype_box");
+  edit_transtype_box=new QComboBox(this);
   edit_transtype_box->setGeometry(385,68,110,26);
   edit_transtype_box->insertItem(tr("Play"));
   edit_transtype_box->insertItem(tr("Segue"));
   edit_transtype_box->insertItem(tr("Stop"));  
-  edit_time_label=new QLabel(edit_transtype_box,"Transition Type:",
-			     this,"edit_transtype_label");
+  edit_time_label=new QLabel(edit_transtype_box,"Transition Type:",this);
   edit_time_label->setGeometry(10,68,370,26);
   edit_time_label->setFont(label_font);
   edit_time_label->setAlignment(AlignRight|AlignVCenter);
@@ -116,27 +111,27 @@ EditMarker::EditMarker(RDLogLine *line,QWidget *parent,const char *name)
   //
   // Comment
   //
-  edit_comment_edit=new QLineEdit(this,"edit_comment_edit");
+  edit_comment_edit=new QLineEdit(this);
   edit_comment_edit->setGeometry(10,116,sizeHint().width()-20,18);
   edit_comment_edit->setMaxLength(255);
-  QLabel *label=new QLabel(tr("Comment"),this,"comment_label");
+  QLabel *label=new QLabel(tr("Comment"),this);
   label->setFont(label_font);
   label->setGeometry(12,100,70,14);
 
   //
   // Label
   //
-  edit_label_edit=new QLineEdit(this,"edit_label_edit");
+  edit_label_edit=new QLineEdit(this);
   edit_label_edit->setGeometry(10,156,100,18);
   edit_label_edit->setMaxLength(10);
-  label=new QLabel(tr("Label"),this,"label_label");
+  label=new QLabel(tr("Label"),this);
   label->setFont(label_font);
   label->setGeometry(12,140,60,14);
 
   //
   //  Ok Button
   //
-  QPushButton *button=new QPushButton(this,"ok_button");
+  QPushButton *button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
   button->setFont(button_font);
@@ -146,7 +141,7 @@ EditMarker::EditMarker(RDLogLine *line,QWidget *parent,const char *name)
   //
   //  Cancel Button
   //
-  button=new QPushButton(this,"cancel_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
   button->setFont(button_font);
