@@ -42,11 +42,13 @@
 #include <btss44.h>
 #include <btss82.h>
 #include <harlond.h>
+#include <kernelgpio.h>
 #include <livewire_lwrpaudio.h>
 #include <livewire_lwrpgpio.h>
 #include <livewire_mcastgpio.h>
 #include <local_audio.h>
 #include <local_gpio.h>
+#include <modbus.h>
 #include <modemlines.h>
 #include <quartz1.h>
 #include <rossnkscp.h>
@@ -141,6 +143,10 @@ bool MainObject::LoadSwitchDriver(int matrix_num)
     ripcd_switcher[matrix_num]=new Harlond(matrix,this);
     break;
 
+  case RDMatrix::KernelGpio:
+    ripcd_switcher[matrix_num]=new KernelGpio(matrix,this);
+    break;
+
   case RDMatrix::LiveWireLwrpAudio:
     ripcd_switcher[matrix_num]=new LiveWireLwrpAudio(matrix,this);
     break;
@@ -165,6 +171,10 @@ bool MainObject::LoadSwitchDriver(int matrix_num)
     ripcd_switcher[matrix_num]=new VGuest(matrix,this);
     break;
 
+  case RDMatrix::Modbus:
+    ripcd_switcher[matrix_num]=new Modbus(matrix,this);
+    break;
+
   case RDMatrix::ModemLines:
     ripcd_switcher[matrix_num]=new ModemLines(matrix,this);
     break;
