@@ -2,9 +2,7 @@
 //
 // A Database Check/Repair Tool for Rivendell.
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rddbcheck.cpp,v 1.18.4.1.2.1 2014/06/02 18:52:22 cvs Exp $
+//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,10 +20,13 @@
 
 #include <limits.h>
 #include <glob.h>
+#include <errno.h>
+#include <fcntl.h>
 #include <signal.h>
 #include <math.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <sys/stat.h>
 #include <sys/types.h>
 
 #include <qapplication.h>
@@ -36,6 +37,7 @@
 #include <rd.h>
 #include <rddbcheck.h>
 #include <rdcart.h>
+#include <rdhash.h>
 #include <rdlog.h>
 #include <rdclock.h>
 #include <rdcreate_log.h>
@@ -49,8 +51,8 @@
 // DB connection will be reset when we detect an error!
 //
 
-MainObject::MainObject(QObject *parent,const char *name)
-  :QObject(parent,name)
+MainObject::MainObject(QObject *parent)
+  :QObject(parent)
 {
   bool skip_db_check=false;
   unsigned schema=0;
@@ -58,6 +60,8 @@ MainObject::MainObject(QObject *parent,const char *name)
   check_yes=false;
   check_no=false;
   QString username="user";
+  relink_audio="";
+  relink_audio_move=false;
 
   //
   // Read Command Options
@@ -83,6 +87,15 @@ MainObject::MainObject(QObject *parent,const char *name)
     if(cmd->key(i)=="--dump-cuts-dir") {
       dump_cuts_dir=cmd->value(i);
     }
+    if(cmd->key(i)=="--relink-audio") {
+      relink_audio=cmd->value(i);
+    }
+    if(cmd->key(i)=="--relink-audio-move") {
+      relink_audio_move=true;
+    }
+    if(cmd->key(i)=="--rehash") {
+      rehash=cmd->value(i);
+    }
   }
   if(check_yes&&check_no) {
     fprintf(stderr,"rddbcheck: '--yes' and '--no' are mutually exclusive\n");
@@ -162,7 +175,6 @@ MainObject::MainObject(QObject *parent,const char *name)
   if(!orphan_group_name.isEmpty()) {
     QString sql=QString().sprintf("select NAME from GROUPS where NAME=\"%s\"",
 				  (const char *)orphan_group_name);
-    printf("SQL: %s\n",(const char *)sql);
     QSqlQuery *q=new QSqlQuery(sql);
     if(!q->first()) {
       fprintf(stderr,"rddbcheck: invalid group \"%s\"\n",
@@ -173,6 +185,14 @@ MainObject::MainObject(QObject *parent,const char *name)
     delete q;
   }
 
+  //
+  // Recover Audio
+  //
+  if(!relink_audio.isEmpty()) {
+    RelinkAudio(relink_audio);
+    exit(0);
+  }
+
   //
   // Check for Orphaned Voice Tracks
   //
@@ -239,6 +259,15 @@ MainObject::MainObject(QObject *parent,const char *name)
   ValidateAudioLengths();
   printf("done.\n\n");
 
+  //
+  // Rehash
+  //
+  if(!rehash.isEmpty()) {
+    printf("Checking hashes...\n");
+    Rehash(rehash);
+    printf("done.\n\n");
+  }
+
   exit(0);
 }
 
@@ -496,7 +525,6 @@ void MainObject::CheckPendingCarts()
     "(PENDING_STATION is not null)&&"+
     "(PENDING_DATETIME<\""+now.addDays(-1).
     toString("yyyy-MM-dd hh:mm:ss")+"\")";
-  printf("SQL: %s\n",(const char *)sql);
   q=new QSqlQuery(sql);
   while(q->next()) {
     printf("  Cart %06u has stale reservation, delete cart(y/N)?",
@@ -687,6 +715,172 @@ void MainObject::ValidateAudioLengths()
 }
 
 
+void MainObject::Rehash(const QString &arg)
+{
+  QString sql;
+  QSqlQuery *q;
+  unsigned cartnum;
+  bool ok=false;
+
+  if(arg.lower()=="all") {
+    sql=QString("select NUMBER from CART where ")+
+      QString().sprintf("TYPE=%d ",RDCart::Audio)+
+      "order by NUMBER";
+    q=new QSqlQuery(sql);
+    while(q->next()) {
+      RehashCart(q->value(0).toUInt());
+    }
+    delete q;
+    return;
+  }
+  cartnum=arg.toUInt(&ok);
+  if(ok&&(cartnum>0)&&(cartnum<=RD_MAX_CART_NUMBER)) {
+    RehashCart(cartnum);
+    return;
+  }
+  RDCut *cut=new RDCut(arg);
+  if(cut->exists()) {
+    RehashCut(arg);
+  }
+  delete cut;
+}
+
+
+void MainObject::RehashCart(unsigned cartnum)
+{
+  RDCart *cart=new RDCart(cartnum);
+  if(cart->exists()) {
+    if(cart->type()==RDCart::Audio) {
+      QString sql=QString("select CUT_NAME from CUTS where ")+
+	QString().sprintf("CART_NUMBER=%u ",cartnum)+
+	"order by CUT_NAME";
+      QSqlQuery *q=new QSqlQuery(sql);
+      while(q->next()) {
+	RehashCut(q->value(0).toString());
+      }
+      delete q;
+    }
+  }
+  else {
+    printf("  Cart %06u does not exist.\n",cartnum);
+  }
+}
+
+
+void MainObject::RehashCut(const QString &cutnum)
+{
+  QString hash=RDSha1Hash(RDCut::pathName(cutnum),true);
+  if(hash.isEmpty()) {
+    printf("  Unable to generate hash for \"%s\"\n",
+	    (const char *)RDCut::pathName(cutnum));
+  }
+  else {
+    RDCut *cut=new RDCut(cutnum);
+    if(cut->exists()) {
+      if(cut->sha1Hash().isEmpty()) {
+	cut->setSha1Hash(hash);
+      }
+      else {
+	if(cut->sha1Hash()!=hash) {
+	  RDCart *cart=new RDCart(RDCut::cartNumber(cutnum));
+	  printf("  Cut %d [%s] in cart %06u [%s] has inconsistent SHA1 hash.  Fix? (y/N) ",
+		 cut->cutNumber(),
+		 (const char *)cut->description(),
+		 cart->number(),
+		 (const char *)cart->title());
+	  fflush(NULL);
+	  if(UserResponse()) {
+	    cut->setSha1Hash(hash);
+	  }
+	  delete cart;
+	}
+      }
+    }
+    else {
+      printf("  Cut \"%s\" does not exist.\n",(const char *)cutnum);
+    }
+    delete cut;
+  }
+}
+
+
+void MainObject::RelinkAudio(const QString &srcdir)
+{
+  QString sql;
+  RDSqlQuery *q;
+
+  QDir dir(srcdir);
+  if(!dir.exists()) {
+    fprintf(stderr,"rddbcheck: --relink-audio directory does not exist\n");
+    exit(256);
+  }
+  QStringList files=dir.entryList(QDir::Files|QDir::Readable|QDir::Hidden);
+  for(unsigned i=0;i<files.size();i++) {
+    QString filename=dir.path()+"/"+files[i];
+    QString hash=RDSha1Hash(filename);
+    QString firstdest;
+    bool delete_source=true;
+    sql=QString("select CUTS.CUT_NAME,CART.TITLE from ")+
+      "CUTS left join CART "+
+      "on CUTS.CART_NUMBER=CART.NUMBER where "+
+      "CUTS.SHA1_HASH=\""+RDEscapeString(hash)+"\"";
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      printf("  Recovering %06u/%03d [%s]...",
+	     RDCut::cartNumber(q->value(0).toString()),
+	     RDCut::cutNumber(q->value(0).toString()),
+	     (const char *)q->value(1).toString());
+      fflush(stdout);
+      if(relink_audio_move) {
+	unlink(RDCut::pathName(q->value(0).toString()));
+	if(link(filename,RDCut::pathName(q->value(0).toString()))<0) {
+	  if(errno==EXDEV) {
+	    if(firstdest.isEmpty()) {
+	      if(CopyFile(RDCut::pathName(q->value(0).toString()),filename)) {
+		firstdest=RDCut::pathName(q->value(0).toString());
+	      }
+	      else {
+		fprintf(stderr,"unable to copy file \"%s\"\n",
+			(const char *)filename);
+		delete_source=false;
+	      }
+	    }
+	    else {
+	      unlink(RDCut::pathName(q->value(0).toString()));
+	      link(firstdest,RDCut::pathName(q->value(0).toString()));
+	    }
+	  }
+	  else {
+	    fprintf(stderr,"unable to move file \"%s\" [%s]\n",
+		    (const char *)filename,strerror(errno));
+	    delete_source=false;
+	  }
+	}
+      }
+      else {
+	if(firstdest.isEmpty()) {
+	  if(CopyFile(RDCut::pathName(q->value(0).toString()),filename)) {
+	    firstdest=RDCut::pathName(q->value(0).toString());
+	  }
+	  else {
+	    fprintf(stderr,"unable to copy file \"%s\"\n",
+		    (const char *)filename);
+	  }
+	}
+	else {
+	  unlink(RDCut::pathName(q->value(0).toString()));
+	  link(firstdest,RDCut::pathName(q->value(0).toString()));
+	}
+      }
+      printf("  done.\n");
+    }
+    if(relink_audio_move&&delete_source) {
+      unlink(filename);
+    }
+  }
+}
+
+
 void MainObject::SetCutLength(const QString &cutname,int len)
 {
   QString sql;
@@ -785,6 +979,46 @@ bool MainObject::IsTableLinked(QSqlQuery *name_q,const QString &ext,
 }
 
 
+bool MainObject::CopyFile(const QString &destfile,const QString &srcfile) const
+{
+  int src_fd=-1;
+  struct stat src_stat;
+  int dest_fd=-1;
+  struct stat dest_stat;
+  int n;
+  int blksize;
+  char *data=NULL;
+
+  if((src_fd=open(srcfile,O_RDONLY))<0) {
+    return false;
+  }
+  fstat(src_fd,&src_stat);
+  mode_t mask=umask(S_IRWXO);
+  if((dest_fd=open(destfile,O_WRONLY|O_CREAT|O_TRUNC,
+		   S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP))<0) {
+    close(src_fd);
+    return false;
+  }
+  umask(mask);
+  fstat(dest_fd,&dest_stat);
+  blksize=src_stat.st_blksize;
+  if(dest_stat.st_blksize<blksize) {
+    blksize=dest_stat.st_blksize;
+  }
+  data=(char *)malloc(blksize);
+  while((n=read(src_fd,data,blksize))!=0) {
+    write(dest_fd,data,n);
+  }
+  free(data);
+  fchown(dest_fd,150,150);  // FIXME: do name lookup!
+  close(dest_fd);
+  close(src_fd);
+  
+
+  return true;
+}
+
+
 bool MainObject::UserResponse()
 {
   char c=0;
@@ -815,6 +1049,6 @@ bool MainObject::UserResponse()
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv,false);
-  new MainObject(NULL,"main");
+  new MainObject();
   return a.exec();
 }
