@@ -2,9 +2,7 @@
 //
 // A Qt-based application for importing Dial Global CDN downloads
 //
-//   (C) Copyright 2012 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rddgimport.cpp,v 1.1.2.12 2014/01/21 21:59:33 cvs Exp $
+//   (C) Copyright 2012,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -44,8 +42,8 @@
 
 #include <rddgimport.h>
 
-MainWidget::MainWidget(QWidget *parent,const char *name)
-  : QWidget(parent,name)
+MainWidget::MainWidget(QWidget *parent)
+  : QWidget(parent)
 {
   dg_user=NULL;
   dg_group=NULL;
@@ -433,6 +431,12 @@ bool MainWidget::CheckSpot(const QString &isci)
   QDate today=QDate::currentDate();
   QDate killdate=dg_date_edit->date().addDays(RDDGIMPORT_KILLDATE_OFFSET);
 
+  QString endDateTimeSQL = "NULL";
+
+  if(killdate.isValid())
+    endDateTimeSQL = RDCheckDateTime(QDateTime(killdate,QTime(23,59,59)),
+                                    "yyyy-MM-dd hh:mm:ss");
+
   sql=QString("select CUT_NAME,CUTS.START_DATETIME,CUTS.END_DATETIME ")+
     "from CART left join CUTS on CART.NUMBER=CUTS.CART_NUMBER "+
     "where (CART.GROUP_NAME=\""+RDEscapeString(dg_svc->autospotGroup())+"\")&&"
@@ -445,7 +449,7 @@ bool MainWidget::CheckSpot(const QString &isci)
       if(q->value(1).isNull()) {
 	sql+="START_DATETIME=\""+today.toString("yyyy-MM-dd")+" 00:00:00\",";
       }
-      sql+="END_DATETIME=\""+killdate.toString("yyyy-MM-dd")+" 23:59:59\" ";
+      sql+="END_DATETIME="+endDateTimeSQL+" ";
       sql+="where CUT_NAME=\""+q->value(0).toString()+"\"";
       q1=new RDSqlQuery(sql);
       delete q1;
@@ -662,7 +666,7 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget(NULL,"main");
+  MainWidget *w=new MainWidget();
   a.setMainWidget(w);
   w->setGeometry(QRect(QPoint(0,0),w->sizeHint()));
   w->show();
