@@ -47,21 +47,21 @@ void Xport::AddLog()
   // Get Arguments
   //
   if(!xport_post->getValue("LOG_NAME",&log_name)) {
-    XmlExit("Missing LOG_NAME",400);
+    XmlExit("Missing LOG_NAME",400,"logs.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("SERVICE_NAME",&service_name)) {
-    XmlExit("Missing SERVICE_NAME",400);
+    XmlExit("Missing SERVICE_NAME",400,"logs.cpp",LINE_NUMBER);
   }
   RDSvc *svc=new RDSvc(service_name);
   if(!svc->exists()) {
-    XmlExit("No such service",404);
+    XmlExit("No such service",404,"logs.cpp",LINE_NUMBER);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->createLog()) {
-    XmlExit("Unauthorized",404);
+    XmlExit("Unauthorized",404,"logs.cpp",LINE_NUMBER);
   }
 
   RDLog *log=new RDLog(log_name);
@@ -70,7 +70,7 @@ void Xport::AddLog()
     log=new RDLog(log_name,true);
     if(!log->exists()) {
       delete log;
-      XmlExit("Unable to create log",500);
+      XmlExit("Unable to create log",500,"logs.cpp",LINE_NUMBER);
     }
     log->setOriginUser(xport_user->name());
     log->setDescription("[new log]");
@@ -79,7 +79,7 @@ void Xport::AddLog()
   delete log;
   RDCreateLogTable(RDLog::tableName(log_name));
 
-  XmlExit("OK",200);
+  XmlExit("OK",200,"logs.cpp",LINE_NUMBER);
 }
 
 
@@ -91,26 +91,26 @@ void Xport::DeleteLog()
   // Get Arguments
   //
   if(!xport_post->getValue("LOG_NAME",&log_name)) {
-    XmlExit("Missing LOG_NAME",400);
+    XmlExit("Missing LOG_NAME",400,"logs.cpp",LINE_NUMBER);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->deleteLog()) {
-    XmlExit("Unauthorized",404);
+    XmlExit("Unauthorized",404,"logs.cpp",LINE_NUMBER);
   }
 
   RDLog *log=new RDLog(log_name);
   if(log->exists()) {
     if(!log->remove(xport_station,xport_user,xport_config)) {
       delete log;
-      XmlExit("Unable to delete log",500);
+      XmlExit("Unable to delete log",500,"logs.cpp",LINE_NUMBER);
     }
   }
   delete log;
 
-  XmlExit("OK",200);
+  XmlExit("OK",200,"logs.cpp",LINE_NUMBER);
 }
 
 
@@ -185,7 +185,7 @@ void Xport::ListLog()
   log=new RDLog(name);
   if(!log->exists()) {
     delete log;
-    XmlExit("No such log",404);
+    XmlExit("No such log",404,"logs.cpp",LINE_NUMBER);
   }
 
   //
@@ -212,7 +212,7 @@ void Xport::SaveLog()
   // Verify User Perms
   //
   if((!xport_user->addtoLog())||(!xport_user->removefromLog())||(!xport_user->arrangeLog())) {
-    XmlExit("No user privilege",404);
+    XmlExit("No user privilege",404,"logs.cpp",LINE_NUMBER);
   }
 
   QString log_name;
@@ -228,28 +228,28 @@ void Xport::SaveLog()
   // Header Data
   //
   if(!xport_post->getValue("LOG_NAME",&log_name)) {
-    XmlExit("Missing LOG_NAME",400);
+    XmlExit("Missing LOG_NAME",400,"logs.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("SERVICE_NAME",&service_name)) {
-    XmlExit("Missing SERVICE_NAME",400);
+    XmlExit("Missing SERVICE_NAME",400,"logs.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("DESCRIPTION",&description)) {
-    XmlExit("Missing DESCRIPTION",400);
+    XmlExit("Missing DESCRIPTION",400,"logs.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("PURGE_DATE",&purge_date)) {
-    XmlExit("Missing PURGE_DATE",400);
+    XmlExit("Missing PURGE_DATE",400,"logs.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("AUTO_REFRESH",&auto_refresh)) {
-    XmlExit("Missing AUTO_REFRESH",400);
+    XmlExit("Missing AUTO_REFRESH",400,"logs.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("START_DATE",&start_date)) {
-    XmlExit("Missing START_DATE",400);
+    XmlExit("Missing START_DATE",400,"logs.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("END_DATE",&end_date)) {
-    XmlExit("Missing END_DATE",400);
+    XmlExit("Missing END_DATE",400,"logs.cpp",LINE_NUMBER);
   }
   if(!xport_post->getValue("LINE_QUANTITY",&line_quantity)) {
-    XmlExit("Missing LINE_QUANTITY",400);
+    XmlExit("Missing LINE_QUANTITY",400,"logs.cpp",LINE_NUMBER);
   }
 
   //
@@ -269,39 +269,39 @@ void Xport::SaveLog()
     bool ok=false;
 
     if(!xport_post->getValue(line+"_ID",&integer1,&ok)) {
-      XmlExit("Missing "+line+"_ID",400);
+      XmlExit("Missing "+line+"_ID",400,"logs.cpp",LINE_NUMBER);
     }
     if(!ok) {
-      XmlExit("Invalid "+line+"_ID",400);
+      XmlExit("Invalid "+line+"_ID",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setId(integer1);
 
     if(!xport_post->getValue(line+"_TYPE",&integer1)) {
-      XmlExit("Missing "+line+"_TYPE",400);
+      XmlExit("Missing "+line+"_TYPE",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setType((RDLogLine::Type)integer1);
 
     if(!xport_post->getValue(line+"_CART_NUMBER",&integer1)) {
-      XmlExit("Missing "+line+"_CART_NUMBER",400);
+      XmlExit("Missing "+line+"_CART_NUMBER",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setCartNumber(integer1);
 
     if(!xport_post->getValue(line+"_START_TIME",&integer1)) {
-      XmlExit("Missing "+line+"_START_TIME",400);
+      XmlExit("Missing "+line+"_START_TIME",400,"logs.cpp",LINE_NUMBER);
     }
     if(!xport_post->getValue(line+"_TIME_TYPE",&integer2)) {
-      XmlExit("Missing "+line+"_TIME_TYPE",400);
+      XmlExit("Missing "+line+"_TIME_TYPE",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setStartTime((RDLogLine::StartTimeType)integer2,
 		     QTime().addMSecs(integer1));
 
     if(!xport_post->getValue(line+"_GRACE_TIME",&integer1)) {
-      XmlExit("Missing "+line+"_GRACE_TIME",400);
+      XmlExit("Missing "+line+"_GRACE_TIME",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setGraceTime(integer1);
 
     if(!xport_post->getValue(line+"_TRANS_TYPE",&str)) {
-      XmlExit("Missing "+line+"_TRANS_TYPE",400);
+      XmlExit("Missing "+line+"_TRANS_TYPE",400,"logs.cpp",LINE_NUMBER);
     }
     integer1=-1;
     if(str.lower()=="play") {
@@ -314,139 +314,140 @@ void Xport::SaveLog()
       integer1=RDLogLine::Stop;
     }
     if(integer1<0) {
-      XmlExit("Invalid transition type in "+line+"_TRANS_TYPE",400);
+      XmlExit("Invalid transition type in "+line+"_TRANS_TYPE",400,
+	      "logs.cpp",LINE_NUMBER);
     }
     ll->setTransType((RDLogLine::TransType)integer1);
 
     if(!xport_post->getValue(line+"_START_POINT",&integer1)) {
-      XmlExit("Missing "+line+"_START_POINT",400);
+      XmlExit("Missing "+line+"_START_POINT",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setStartPoint(integer1,RDLogLine::LogPointer);
 
     if(!xport_post->getValue(line+"_END_POINT",&integer1)) {
-      XmlExit("Missing "+line+"_END_POINT",400);
+      XmlExit("Missing "+line+"_END_POINT",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setEndPoint(integer1,RDLogLine::LogPointer);
 
     if(!xport_post->getValue(line+"_SEGUE_START_POINT",&integer1)) {
-      XmlExit("Missing "+line+"_SEGUE_START_POINT",400);
+      XmlExit("Missing "+line+"_SEGUE_START_POINT",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setSegueStartPoint(integer1,RDLogLine::LogPointer);
 
     if(!xport_post->getValue(line+"_SEGUE_END_POINT",&integer1)) {
-      XmlExit("Missing "+line+"_SEGUE_END_POINT",400);
+      XmlExit("Missing "+line+"_SEGUE_END_POINT",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setSegueEndPoint(integer1,RDLogLine::LogPointer);
 
     if(!xport_post->getValue(line+"_FADEUP_POINT",&integer1)) {
-      XmlExit("Missing "+line+"_FADEUP_POINT",400);
+      XmlExit("Missing "+line+"_FADEUP_POINT",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setFadeupPoint(integer1,RDLogLine::LogPointer);
 
     if(!xport_post->getValue(line+"_FADEDOWN_POINT",&integer1)) {
-      XmlExit("Missing "+line+"_FADEDOWN_POINT",400);
+      XmlExit("Missing "+line+"_FADEDOWN_POINT",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setFadedownPoint(integer1,RDLogLine::LogPointer);
 
     if(!xport_post->getValue(line+"_DUCK_UP_GAIN",&integer1)) {
-      XmlExit("Missing "+line+"_DUCK_UP_GAIN",400);
+      XmlExit("Missing "+line+"_DUCK_UP_GAIN",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setDuckUpGain(integer1);
 
     if(!xport_post->getValue(line+"_DUCK_DOWN_GAIN",&integer1)) {
-      XmlExit("Missing "+line+"_DUCK_DOWN_GAIN",400);
+      XmlExit("Missing "+line+"_DUCK_DOWN_GAIN",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setDuckDownGain(integer1);
 
     if(!xport_post->getValue(line+"_COMMENT",&str)) {
-      XmlExit("Missing "+line+"_COMMENT",400);
+      XmlExit("Missing "+line+"_COMMENT",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setMarkerComment(str);
 
     if(!xport_post->getValue(line+"_LABEL",&str)) {
-      XmlExit("Missing "+line+"_LABEL",400);
+      XmlExit("Missing "+line+"_LABEL",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setMarkerLabel(str);
 
     if(!xport_post->getValue(line+"_ORIGIN_USER",&str)) {
-      XmlExit("Missing "+line+"_ORIGIN_USER",400);
+      XmlExit("Missing "+line+"_ORIGIN_USER",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setOriginUser(str);
 
     if(!xport_post->getValue(line+"_ORIGIN_DATETIME",&datetime)) {
-      XmlExit("Missing "+line+"_ORIGIN_DATETIME",400);
+      XmlExit("Missing "+line+"_ORIGIN_DATETIME",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setOriginDateTime(datetime);
 
     if(!xport_post->getValue(line+"_EVENT_LENGTH",&integer1)) {
-      XmlExit("Missing "+line+"_EVENT_LENGTH",400);
+      XmlExit("Missing "+line+"_EVENT_LENGTH",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setEventLength(integer1);
 
     if(!xport_post->getValue(line+"_LINK_EVENT_NAME",&str)) {
-      XmlExit("Missing "+line+"_LINK_EVENT_NAME",400);
+      XmlExit("Missing "+line+"_LINK_EVENT_NAME",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setLinkEventName(str);
 
     if(!xport_post->getValue(line+"_LINK_START_TIME",&integer1)) {
-      XmlExit("Missing "+line+"_LINK_START_TIME",400);
+      XmlExit("Missing "+line+"_LINK_START_TIME",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setLinkStartTime(QTime().addMSecs(integer1));
 
     if(!xport_post->getValue(line+"_LINK_LENGTH",&integer1)) {
-      XmlExit("Missing "+line+"_LINK_LENGTH",400);
+      XmlExit("Missing "+line+"_LINK_LENGTH",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setLinkLength(integer1);
 
     if(!xport_post->getValue(line+"_LINK_START_SLOP",&integer1)) {
-      XmlExit("Missing "+line+"_LINK_START_SLOP",400);
+      XmlExit("Missing "+line+"_LINK_START_SLOP",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setLinkStartSlop(integer1);
 
     if(!xport_post->getValue(line+"_LINK_END_SLOP",&integer1)) {
-      XmlExit("Missing "+line+"_LINK_END_SLOP",400);
+      XmlExit("Missing "+line+"_LINK_END_SLOP",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setLinkEndSlop(integer1);
 
     if(!xport_post->getValue(line+"_LINK_ID",&integer1)) {
-      XmlExit("Missing "+line+"_LINK_ID",400);
+      XmlExit("Missing "+line+"_LINK_ID",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setLinkId(integer1);
 
     if(!xport_post->getValue(line+"_LINK_EMBEDDED",&state)) {
-      XmlExit("Missing "+line+"_LINK_EMBEDDED",400);
+      XmlExit("Missing "+line+"_LINK_EMBEDDED",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setLinkEmbedded(state);
 
     if(!xport_post->getValue(line+"_EXT_START_TIME",&time)) {
-      XmlExit("Missing "+line+"_EXT_START_TIME",400);
+      XmlExit("Missing "+line+"_EXT_START_TIME",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setExtStartTime(time);
 
     if(!xport_post->getValue(line+"_EXT_CART_NAME",&str)) {
-      XmlExit("Missing "+line+"_EXT_CART_NAME",400);
+      XmlExit("Missing "+line+"_EXT_CART_NAME",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setExtCartName(str);
 
     if(!xport_post->getValue(line+"_EXT_DATA",&str)) {
-      XmlExit("Missing "+line+"_EXT_DATA",400);
+      XmlExit("Missing "+line+"_EXT_DATA",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setExtData(str);
 
     if(!xport_post->getValue(line+"_EXT_EVENT_ID",&str)) {
-      XmlExit("Missing "+line+"_EXT_EVENT_ID",400);
+      XmlExit("Missing "+line+"_EXT_EVENT_ID",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setExtEventId(str);
 
     if(!xport_post->getValue(line+"_EXT_ANNC_TYPE",&str)) {
-      XmlExit("Missing "+line+"_EXT_ANNC_TYPE",400);
+      XmlExit("Missing "+line+"_EXT_ANNC_TYPE",400,"logs.cpp",LINE_NUMBER);
     }
     ll->setExtAnncType(str);
   }
 
   RDLog *log=new RDLog(log_name);
   if(!log->exists()) {
-    XmlExit("No such log",404);
+    XmlExit("No such log",404,"logs.cpp",LINE_NUMBER);
   }
   log->setService(service_name);
   log->setDescription(description);
@@ -454,8 +455,10 @@ void Xport::SaveLog()
   log->setAutoRefresh(auto_refresh);
   log->setStartDate(start_date);
   log->setEndDate(end_date);
+  log->setModifiedDatetime(QDateTime::currentDateTime());
 
   logevt->save();
 
-  XmlExit(QString().sprintf("OK Saved %d events",logevt->size()),200);
+  XmlExit(QString().sprintf("OK Saved %d events",logevt->size()),
+	  200,"logs.cpp",LINE_NUMBER);
 }
